==> blesta-5.10.2.zip: blesta/plugins/webhooks/language/es_es/webhooks_webhooks.php <==
<?php
/**
 * Webhooks Webhooks
 *
 * @package blesta
 * @subpackage blesta.language.es_es
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['WebhooksWebhooks.getMethods.json'] = 'JSON';
$lang['WebhooksWebhooks.getMethods.post'] = 'POST';
$lang['WebhooksWebhooks.getMethods.get'] = 'GET';
$lang['WebhooksWebhooks.getTypes.type_outgoing'] = 'Saliente';
$lang['WebhooksWebhooks.getTypes.type_incoming'] = 'Entrante';
$lang['WebhooksWebhooks.!error.fields[][parameter].length'] = 'El nombre del parámetro no puede superar los 255 caracteres.';
$lang['WebhooksWebhooks.!error.fields[][parameter].empty'] = 'El parámetro del campo no puede estar vacío.';
$lang['WebhooksWebhooks.!error.fields[][field].length'] = 'El nombre del campo no puede superar los 255 caracteres.';
$lang['WebhooksWebhooks.!error.fields[][field].empty'] = 'El nombre del campo no puede estar vacío.';
$lang['WebhooksWebhooks.!error.method.valid'] = 'Seleccione un método válido.';
$lang['WebhooksWebhooks.!error.type.valid'] = 'Seleccione un tipo válido.';
$lang['WebhooksWebhooks.!error.event.exists'] = 'El evento proporcionado no existe.';
$lang['WebhooksWebhooks.!error.callback.length'] = 'La llamada de retorno no puede superar los 255 caracteres.';
$lang['WebhooksWebhooks.!error.callback.empty'] = 'Por favor, introduzca una devolución de llamada válida.';
$lang['WebhooksWebhooks.!error.callback.exists'] = 'Ya existe un webhook de este tipo con esta devolución de llamada.';
$lang['WebhooksWebhooks.!error.company_id.exists'] = 'La empresa indicada no existe.';

==> blesta-5.11.4.zip: blesta/plugins/webhooks/language/es_es/webhooks_webhooks.php <==
<?php
/**
 * Webhooks Webhooks
 *
 * @package blesta
 * @subpackage blesta.language.es_es
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['WebhooksWebhooks.getMethods.json'] = 'JSON';
$lang['WebhooksWebhooks.getMethods.post'] = 'POST';
$lang['WebhooksWebhooks.getMethods.get'] = 'GET';
$lang['WebhooksWebhooks.getTypes.type_outgoing'] = 'Saliente';
$lang['WebhooksWebhooks.getTypes.type_incoming'] = 'Entrante';
$lang['WebhooksWebhooks.!error.fields[][parameter].length'] = 'El nombre del parámetro no puede superar los 255 caracteres.';
$lang['WebhooksWebhooks.!error.fields[][parameter].empty'] = 'El parámetro del campo no puede estar vacío.';
$lang['WebhooksWebhooks.!error.fields[][field].length'] = 'El nombre del campo no puede superar los 255 caracteres.';
$lang['WebhooksWebhooks.!error.fields[][field].empty'] = 'El nombre del campo no puede estar vacío.';
$lang['WebhooksWebhooks.!error.method.valid'] = 'Seleccione un método válido.';
$lang['WebhooksWebhooks.!error.type.valid'] = 'Seleccione un tipo válido.';
$lang['WebhooksWebhooks.!error.event.exists'] = 'El evento proporcionado no existe.';
$lang['WebhooksWebhooks.!error.callback.length'] = 'La llamada de retorno no puede superar los 255 caracteres.';
$lang['WebhooksWebhooks.!error.callback.empty'] = 'Por favor, introduzca una devolución de llamada válida.';
$lang['WebhooksWebhooks.!error.callback.exists'] = 'Ya existe un webhook de este tipo con esta devolución de llamada.';
$lang['WebhooksWebhooks.!error.company_id.exists'] = 'La empresa indicada no existe.';
$lang['WebhooksWebhooks.getMethods.put_json'] = 'PUT JSON';
$lang['WebhooksWebhooks.getMethods.post_json'] = 'POST JSON';
$lang['WebhooksWebhooks.getMethods.put'] = 'PUT';
$lang['WebhooksWebhooks.!error.events[].exists'] = 'El evento proporcionado no existe.';
